/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-11-23 15:50:18.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.config;

import cn.com.qmth.examcloud.core.print.common.utils.DateUtils;
import cn.com.qmth.examcloud.core.print.service.CoursePaperService;
import cn.com.qmth.examcloud.core.print.service.CourseStatisticService;
import cn.com.qmth.examcloud.core.print.service.PrintingProjectService;
import cn.com.qmth.examcloud.core.print.service.PrintingProjectStatisticService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.io.Serializable;
import java.util.Date;

@Component
public class StatisticScheduler implements Serializable {
    private static final Logger log = LoggerFactory.getLogger(StatisticScheduler.class);
    private static final long serialVersionUID = 1L;
    @Autowired
    private CourseStatisticService courseStatisticService;
    @Autowired
    private PrintingProjectService printingProjectService;
    @Autowired
    private PrintingProjectStatisticService printingProjectStatisticService;
    @Autowired
    private CoursePaperService coursePaperService;

    /**
     * 定时统计数据(每N分钟执行)
     */
    //@Scheduled(cron = "0 1/1 * * * ?")
    public void statistic() throws Exception {
        log.debug("Statistic Schedule start...");
        Date start = new Date();

        //初始所有印刷项目的基本信息
        printingProjectService.initAllPrintingProject();

        //初始所有课程的统计信息
        courseStatisticService.initAllCourseStatistic();

        //初始所有印刷项目的统计信息
        printingProjectStatisticService.initAllPrintingProjectStatistic();
        log.debug("Statistic Schedule finished..." + DateUtils.diff(start, new Date()));
    }

    /**
     * 定时执行转换PDF(每N分钟执行)
     */
    @Scheduled(cron = "0 3/3 * * * ?")
    public void convert() throws Exception {
        log.debug("Convert Schedule start...");
        Date start = new Date();

        coursePaperService.convertCoursePapers();
        log.debug("Convert Schedule finished..." + DateUtils.diff(start, new Date()));
    }

}